<?php
if (!defined('_PS_VERSION_')) {
    exit;
}

class CcsClearCache extends Module
{
    public $tabs = array(
        array(
            'name' => 'Clear Ccs Cache', // One name for all langs
            'class_name' => 'AdminClearccscache',
            'visible' => true,
            'parent_class_name' => 'CONFIGURE',
            'icon' => 'logo',
        ));

    public function __construct()
    {

        $this->name = 'ccsclearcache';
//        $this->tab = 'front_office_features';
        $this->version = '1.0.0';
        $this->author = 'softdreams';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.6',
            'max' => _PS_VERSION_
        ];
        $this->bootstrap = true;

        parent::__construct();
        $this->displayName = $this->l('Ccsclearcache');
        $this->description = $this->l('Triggers the clearccscache cache on the ccs servers');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        if (!Configuration::get('CCSCLEARCACHE')) {
            $this->warning = $this->l('No name provided');
        }
    }


    public function install()
    {
        if (!parent::install() ||
            !$this->registerHook('actionProductSave') ||
            !$this->registerHook('actionProductUpdate')||
            !$this->registerHook('actionProductAdd') ||
            !$this->registerHook('updateProduct')||
            !$this->registerHook('actionCategoryAdd') ||
            !$this->registerHook('categoryUpdate') ||
            !$this->registerHook('actionAttributeUpdate') ||
            !$this->registerHook('actionObjectProductUpdateAfter')||
            !$this->registerHook('actionFeatureSave') ||
            !$this->registerHook('displayBackOfficeHeader') ||
            !$this->registerHook('actionAttributeSave') && $this->installTab()
        )
        {
                    return false;
        }
        return true;
    }

    public function uninstall()
    {
        return parent::uninstall()&& $this->uninstallTab();

    }
    private function installTab()
    {
        $tabId = (int) Tab::getIdFromClassName('AdminClearccscacheController');
        if (!$tabId) {
            $tabId = null;
        }

        $tab = new Tab($tabId);
        $tab->active = 1;
        $tab->class_name = 'AdminClearccscacheController';
        $tab->name = array();
        foreach (Language::getLanguages(true) as $lang) {
            $tab->name[$lang['id_lang']] = 'Clear Ccs Demo';
        }
        $tab->id_parent = (int) Tab::getIdFromClassName('CONFIGURE');
        $tab->module = $this->name;
        $tab->icon = "logo";
        return $tab->save();
    }

    private function uninstallTab()
    {
        $tabId = (int) Tab::getIdFromClassName('AdminClearccscacheController');
        if (!$tabId) {
            return true;
        }

        $tab = new Tab($tabId);

        return $tab->delete();
    }
    public function getContent()
    {
        $output = null;

        if (Tools::isSubmit('submit' . $this->name)) {
            $ccsClearCacheUrl = strval(Tools::getValue('CCS_CLEAR_CACHE_URL'));
            $deletePostCache = strval(Tools::getValue('DELETE_POST_CACHE'));

            if (
                !$ccsClearCacheUrl ||
                empty($ccsClearCacheUrl) ||
                !Validate::isGenericName($ccsClearCacheUrl)
            ) {
                $output .= $this->displayError($this->l('Invalid url'));
            } else {
                Configuration::updateValue('CCS_CLEAR_CACHE_URL', $ccsClearCacheUrl);
                Configuration::updateValue('DELETE_POST_CACHE', $deletePostCache);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
            if( (!$deletePostCache &&
                $deletePostCache != "0") ||
                !Validate::isGenericName( $deletePostCache))
            {
                $output .= $this->displayError($this->l('Error choice'));
            }
            else {
                Configuration::updateValue('DELETE_POST_CACHE', $deletePostCache);

            }
        }

        return $output . $this->displayForm();
    }

    public function displayForm()
    {
        // Get default language
        $defaultLang = (int)Configuration::get('PS_LANG_DEFAULT');

        // Init Fields form array
        $fieldsForm[0]['form'] = [
            'legend' => [
                'title' => $this->l('Settings'),
            ],
            'input' => [
                [
                    'type' => 'text',
                    'label' => $this->l('Clear cache path'),
                    'name' => 'CCS_CLEAR_CACHE_URL',
                    'size' => 20,
                    'required' => true
                ],
                [
                    'type' => 'radio',
                    'label' =>  $this->l('Automatically delete page/post cache on edit?'),
                    'name' => 'DELETE_POST_CACHE',
                    'required' => true,
                    'values' => array(
                            array(
                                'id' => 'no',
                                'value' => 0,
                                'label' => $this->l('no')
                            ),
                            array(
                                'id' => 'yes',
                                'value' => 1,
                                'label' => $this->l('yes')
                            )
                        )
                ]
            ],
            'submit' => [
                'title' => $this->l('Save'),
                'class' => 'btn btn-default pull-right'
            ]
        ];

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

        // Language
        $helper->default_form_language = $defaultLang;
        $helper->allow_employee_form_lang = $defaultLang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit' . $this->name;
        $helper->toolbar_btn = [
            'save' => [
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex . '&configure=' . $this->name . '&save' . $this->name .
                    '&token=' . Tools::getAdminTokenLite('AdminModules'),
            ],
            'back' => [
                'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            ]
        ];

        // Load current value
        $helper->fields_value['CCS_CLEAR_CACHE_URL'] = Configuration::get('CCS_CLEAR_CACHE_URL');
        $helper->fields_value['DELETE_POST_CACHE'] = Configuration::get('DELETE_POST_CACHE');

        return $helper->generateForm($fieldsForm);
    }
    /** triggerSentCurlMethod loads the controller AdminClearccscacheController and calls method sendCurlRequest */
    public function triggerSentCurlMethod(){
        $file = _PS_MODULE_DIR_.'/'.$this->name.'/controllers/admin/AdminClearccscacheController.php';
        require_once $file;
        $obj = new AdminClearccscacheController();
        return $obj->sendCurlRequest();
    }
    public function hookActionProductSave(){
        $this->triggerSentCurlMethod();
    }
    public function hookActionProductUpdate(){
        $this->triggerSentCurlMethod();
    }
    public function hookActionProductAdd(){
        $this->triggerSentCurlMethod();
    }
    public function hookUpdateProduct(){
        $this->triggerSentCurlMethod();
    }
    public function hookActionCategoryAdd(){
        $this->triggerSentCurlMethod();
    }
    public function hookCategoryUpdate(){
        $this->triggerSentCurlMethod();
    }
    public function hookActionAttributeUpdate(){
        $this->triggerSentCurlMethod();
    }
    public function hookActionObjectProductUpdateAfter(){
        $this->triggerSentCurlMethod();
    }
    public function hookActionFeatureSave(){
        $this->triggerSentCurlMethod();
    }
    public function hookActionAttributeSave(){
        $this->triggerSentCurlMethod();
    }
    public function hookDisplayBackOfficeHeader($params) {
        $this->context->controller->addCSS(($this->_path) . 'menuTabIcon.css');
    }

}